@@ -1203,6 +1203,7 @@ class InternetArchiveItem(models.Model):
                 task = progress.add_task("[red]Importing...", total=file_size)
 
                 count = 0
+                sample_count = 0
                 batch_objects = []
 
                 utils.clear_out(InternetArchiveItem)
@@ -1221,9 +1222,6 @@ class InternetArchiveItem(models.Model):
                     progress.update(task, advance=len(json_data))
 
                     for outcome, url in list_comp:
-                        # print(f"{url}, {outcome.ext_ids.doi},
-                        # {outcome.ident}")
-
                         batch_objects.append(
                             InternetArchiveItem(
                                 doi=outcome.ext_ids.doi,
@@ -1232,16 +1230,28 @@ class InternetArchiveItem(models.Model):
                             )
                         )
 
+                        # this is just a logging function so we can see
+                        # what's going on
+                        if sample_count == 1000:
+                            progress.console.print(
+                                f"{url}, {outcome.ext_ids.doi}, {outcome.ident}"
+                            )
+                            sample_count = 0
+
                         count += 1
 
+                    sample_count += 1
+
                     if count == 1000:
                         InternetArchiveItem.objects.bulk_create(batch_objects)
-                        logging.info(f"Flushing {len(batch_objects)} items.")
+                        progress.console.print(
+                            f"Flushing {len(batch_objects)} items."
+                        )
                         count = 0
                         batch_objects = []
 
                 # flush the final objects
                 InternetArchiveItem.objects.bulk_create(batch_objects)
-                logging.info(f"Flushing {len(batch_objects)} items.")
+                progress.console.print(f"Flushing {len(batch_objects)} items.")
 
             return
